@@ -14,6 +14,11 @@ import org.gnu.glib.Type;
  * GnomeCanvas. The line can contain multiple segments.
  */
 public class CanvasLine extends CanvasItem {
+
+	public CanvasLine(CanvasGroup group) {
+		super(group, gnome_canvas_line_get_type());
+	}
+
 	/**
 	 * Constructs an instance of CanvasLine from a native widget resource.
 	 * @param handle The handle to the native widget.
